summaryrefslogtreecommitdiffstats
path: root/bin/schroot-create.sh
diff options
context:
space:
mode:
Diffstat (limited to 'bin/schroot-create.sh')
-rwxr-xr-xbin/schroot-create.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/bin/schroot-create.sh b/bin/schroot-create.sh
index 25e7fa48..adecb729 100755
--- a/bin/schroot-create.sh
+++ b/bin/schroot-create.sh
@@ -127,17 +127,17 @@ bootstrap() {
done
set -x
sudo chroot $CHROOT_TARGET apt-get update
# install debbindiff with all recommends...
if [ "$1" = "debbindiff" ] ; then
sudo chroot $CHROOT_TARGET apt-get install -y --install-recommends debbindiff
fi
sudo chroot $CHROOT_TARGET apt-get install -y --no-install-recommends "$@" sudo
# always use debbindiff from unstable
if [ "$SUITE" = "testing" ] && [ "$1" = "debbindiff" ] ; then
echo "deb $MIRROR unstable main" | sudo tee -a $CHROOT_TARGET/etc/apt/sources.list > /dev/null
sudo chroot $CHROOT_TARGET apt-get update
- # install debbindiff from unstable without re-adding all recommends...
- sudo chroot $CHROOT_TARGET apt-get install -y -t unstable --no-install-recommends debbindiff || echo "Warning: debbindiff from unstable is uninstallable at the moment."
+ # install diffoscope from unstable without re-adding all recommends...
+ sudo chroot $CHROOT_TARGET apt-get install -y -t unstable --no-install-recommends debbindiff || echo "Warning: diffoscope from unstable is uninstallable at the moment."
fi
if ! $DEBUG ; then set +x ; fi
if [ "$1" = "debbindiff" ] ; then
@@ -127,17 +127,17 @@ bootstrap() {
set -x
sudo chroot $CHROOT_TARGET apt-get update
- # install debbindiff with all recommends...
+ # install diffoscope with all recommends...
if [ "$1" = "debbindiff" ] ; then
sudo chroot $CHROOT_TARGET apt-get install -y --install-recommends debbindiff
@@ -127,17 +127,17 @@ bootstrap() {
fi
sudo chroot $CHROOT_TARGET apt-get install -y --no-install-recommends "$@" sudo
- # always use debbindiff from unstable
+ # always use diffoscope from unstable
if [ "$SUITE" = "testing" ] && [ "$1" = "debbindiff" ] ; then
echo "deb $MIRROR unstable main" | sudo tee -a $CHROOT_TARGET/etc/apt/sources.list > /dev/null